==> hyades.source_1.0.3_20030929_1406.zip: org/eclipse/hyades/trace/views/actions/internal/OpenTraceViewAction.java <==
/**********************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/
package org.eclipse.hyades.trace.views.actions.internal;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.hyades.trace.ui.HyadesUtil;
import org.eclipse.jface.action.Action;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.ui.*;

/**
 * @author popescu
 *
 * To change the template for this generated type comment go to
 * Window>Preferences>Java>Code Generation>Code and Comments
 */
public abstract class OpenTraceViewAction extends Action
										  implements IWorkbenchWindowActionDelegate, IViewActionDelegate
{
	/**
	 * @param label
	 */
	public OpenTraceViewAction(String label) {
		super(label);
	}

	/**
	 * @param label
	 * @param image
	 */
	public OpenTraceViewAction(String label, ImageDescriptor image) {
		super(label, image);
	}

	public EObject getMofObject()
	{
		return HyadesUtil.getSelectedObject();  
	}

	/*
	 * 
	 */
	public void selectionChanged(IAction action, ISelection selection) {
		
	}

	/*
	 * 
	 */
	public void init(IWorkbenchWindow window) {
	}
	
	/**
	 * Initializes this action delegate with the view it will work in.
	 *
	 * @param view the view that provides the context for this delegate
	 */
	public void init(IViewPart view)
	{
	}

	public void dispose()
	{
	}
	
}

==> hyades.source_3.3.0_20050623_2150.zip: org/eclipse/hyades/trace/views/actions/internal/OpenTraceViewAction.java <==
/**********************************************************************
 * Copyright (c) 2005 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * $Id: OpenTraceViewAction.java,v 1.8 2005/03/23 21:05:47 ewchan Exp $
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/
package org.eclipse.hyades.trace.views.actions.internal;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.hyades.trace.ui.HyadesUtil;
import org.eclipse.jface.action.Action;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.ui.*;

/**
 * @author popescu
 *
 * To change the template for this generated type comment go to
 * Window>Preferences>Java>Code Generation>Code and Comments
 */
public abstract class OpenTraceViewAction extends Action
										  implements IWorkbenchWindowActionDelegate, IViewActionDelegate
{
	/**
	 * @param label
	 */
	public OpenTraceViewAction(String label) {
		super(label);
	}

	/**
	 * @param label
	 * @param image
	 */
	public OpenTraceViewAction(String label, ImageDescriptor image) {
		super(label, image);
	}

	public EObject getMofObject()
	{
		return HyadesUtil.getMofObject();  
	}

	/*
	 * 
	 */
	public void selectionChanged(IAction action, ISelection selection) {
		
	}

	/*
	 * 
	 */
	public void init(IWorkbenchWindow window) {
	}
	
	/**
	 * Initializes this action delegate with the view it will work in.
	 *
	 * @param view the view that provides the context for this delegate
	 */
	public void init(IViewPart view)
	{
	}

	public void dispose()
	{
	}
	
}
